@@ -21,6 +21,14 @@ class Buffer():
         self.timer.start()
         return
 
+    def pause_all(self):
+        for key in self.can_record:
+            self.can_record[key] = False
+
+    def resume_all(self):
+        for key in self.can_record:
+            self.can_record[key] = True
+
     def stop(self, key):
         self.can_record[key] = False
 
