@@ -20,12 +20,11 @@ def mlmodel_info_at_path(dirpath: str):
         return None
 
 def upload_mlmodel(source_path: str, mlmodel_name: str, project_path: str, run_id: str = None, version: str = None,
-    short_description: str = None, push_dir:bool = False):
+    short_description: str = None, push_dir:bool = False, resume_upload: bool = False):
 
     slug_mlmodel_name = slugify(mlmodel_name)
     assert slug_mlmodel_name==mlmodel_name, f"The name is not slugified. Please use {slug_mlmodel_name} instead."
 
-
     manager = load_event_manager()
 
     if version is not None:
@@ -48,7 +47,7 @@ def upload_mlmodel(source_path: str, mlmodel_name: str, project_path: str, run_i
         filenames = [os.path.basename(source_path)]
         full_paths = {os.path.basename(source_path): os.path.abspath(source_path) }
         num_bytes = [os.path.getsize(source_path)]
-    args = (run_id, project_path, filenames, full_paths, num_bytes, mlmodel_name, short_description, version)
+    args = (run_id, project_path, filenames, full_paths, num_bytes, mlmodel_name, short_description, version, resume_upload)
     return manager.add_event("add_mlmodel", args, async_method=False)
 
 def download_mlmodel(mlmodel_name: str,
@@ -62,7 +61,7 @@ def download_mlmodel(mlmodel_name: str,
     if version is not None:
         dirpath = os.path.join(save_path, mlmodel_name+'-'+version)
         if os.path.isdir(dirpath) and overwrite==False:
-            logger.warning(f'Dataset is already downloaded at {dirpath}. Delete this folder or set overwrite==True to download again.')
+            logger.warning(f'Model is already downloaded at {dirpath}. Delete this folder or set overwrite==True to download again.')
             return dirpath
 
     page = 1
@@ -76,7 +75,7 @@ def download_mlmodel(mlmodel_name: str,
     logger.info(f'Fetching version {version}')
 
     if os.path.isdir(dirpath) and overwrite==False:
-        logger.warning(f'Dataset is already downloaded at {dirpath}. Delete this folder or set overwrite==True to download again.')
+        logger.warning(f'Model is already downloaded at {dirpath}. Delete this folder or set overwrite==True to download again.')
         return dirpath
 
     if os.path.isdir(dirpath)==False:
