@@ -90,6 +90,19 @@ def create_run(name, project_path, token):
                 body_args=dict(name=name))
     return res
 
+def pulse(path, project_path, token):
+    res = lab_request(path=f"/{project_path}/runs/{path}/heartbeat", 
+                request_type="POST", 
+                token=token)
+    return res
+
+def ack_pulse(path, project_path, key, token):
+    res = lab_request(path=f"/{project_path}/runs/{path}/ack_message", 
+                request_type="POST", 
+                query_args=dict(key=key),
+                token=token)
+    return res
+
 def fetch_run(path, project_path, token):
     res = lab_request(path=f"/{project_path}/runs/{path}", 
                 request_type="GET", 
