@@ -4,7 +4,9 @@ import sys
 from pyhectiqlab.metrics import MetricsManager
 from pyhectiqlab.settings import app_url
 from pyhectiqlab.events_manager import EventsManager
+from pyhectiqlab.pulse import PulseManager
 from pyhectiqlab.stream import LogHandler
+from pyhectiqlab.utils import Skip
 from pyhectiqlab.buffer import Buffer
 from pyhectiqlab.watermark import Watermark
 from pyhectiqlab.notebooks import get_notebook_file
@@ -17,6 +19,7 @@ from pyhectiqlab.datasets import upload_dataset as ops_upload_dataset
 from pyhectiqlab.mlmodels import mlmodel_info_at_path
 from pyhectiqlab.datasets import dataset_info_at_path
 
+from contextlib import contextmanager
 from functools import partial
 from typing import Optional, Union
 import tempfile
@@ -125,6 +128,7 @@ class Run():
         self.add_log_stream("pyhectiqlab", level=logging.INFO)
         self.tmp_artifacts = None
         self.metrics_group = None
+        self.pulse = PulseManager(run_path=self._id, project=self._project_path, mock=self._read_only)
 
     def user_is_not_logged(self):
         print("User not authentificated. Use `hectiqlab add-profile` in command line.")
@@ -137,6 +141,19 @@ class Run():
         self.metrics_manager = None
         self.logs_buffer = Buffer(push_method=self._push_logs)
 
+    @contextmanager
+    def message(self, key: str):
+        content = self.pulse[key]
+        message = Skip(content)
+        try:
+            yield message
+        except ValueError as err:
+            if err != Skip.error:
+                raise err
+        finally:
+            if content:
+                self.pulse.ack(key)
+
     @write_method
     @action_method
     def add_figure(self, fig: "matplotlib.figure.Figure", 
@@ -588,6 +605,7 @@ class Run():
             else:
                 self.add_tag(name="failed")
                 self.failed()
+            self.pulse.stop()
             l = self.add_log_stream("pyhectiqlab", level=logging.ERROR)
             l.critical("Automatic exception handler", exc_info=(exc_type, exc_value, exc_traceback))
 
