@@ -1,5 +1,4 @@
 import os
-from pathlib import Path
 import logging
 import ast
 import requests
@@ -9,38 +8,12 @@ from pyhectiqlab.config import Config
 from pyhectiqlab.events_manager import EventsManager
 
 logger = logging.getLogger('pyhectiqlab')
-logger.setLevel(logging.WARNING)
 
 def load_event_manager():
     events_manager = EventsManager()
     assert events_manager.is_logged(), "User not authentificated"
     return events_manager
 
-def get_single_user_project():
-
-    manager = load_event_manager()
-    projects = manager.add_event("get_all_projects", args=(), auth=True, async_method=False)
-    if len(projects["result"])==1:
-        project = projects["result"][0]
-        logger.info(f"Connecting to project {project['name']}.")
-        return project
-    else:
-        logger.error("User has access to multiple projects.")
-        return
-
-def run_config(run_id: str):
-    """Fetch the config file of an existing run.
-    """
-    events_manager = load_event_manager()
-    run_view = events_manager.add_event('get_existing_run_info', 
-        (run_id, ), 
-        auth=True, async_method=False)
-    logger.info(f"Run {run_id}: {run_view['name']}")
-    if 'custom_fields' not in run_view:
-        return Config()
-
-    return convert_custom_fields_to_config(run_view['custom_fields'])
-
 def download_existing_run_artifact(artifact_uuid: str, savepath: str = "./"):
     events_manager = load_event_manager()
     data = events_manager.add_event('get_artifact_signed_url', 
@@ -73,6 +46,9 @@ def download_existing_run_artifact(artifact_uuid: str, savepath: str = "./"):
     logger.info(f'Content saved at {path}')
     return path
 
+def download_run_artifact(artifact_uuid: str, savepath: str = "./"):
+    return download_existing_run_artifact(artifact_uuid=artifact_uuid, savepath=savepath)
+    
 def convert_custom_fields_to_config(data: dict):
     """Convert a dict representation of a config file
     into a Config object.
@@ -108,7 +84,6 @@ def convert_custom_fields_to_config(data: dict):
     return config
 
 def list_all_files_in_dir(local_folder: str):
-    path_object = Path(local_folder)
     filenames = []
     for el in os.walk(local_folder):
         for f in os.listdir(el[0]):
@@ -116,4 +91,14 @@ def list_all_files_in_dir(local_folder: str):
             if os.path.isdir(complete_path)==False:
                 if os.path.isfile(complete_path):
                     filenames.append(complete_path)
-    return filenames
\ No newline at end of file
+    return filenames
+
+
+class Skip():
+    error = ValueError("Skipping context execution")
+    def __init__(self, msg):
+        self.content = msg
+            
+    @staticmethod
+    def skip():
+        raise Skip.error
\ No newline at end of file
